@@ -99,9 +99,10 @@ my %CONSTANTS = (
    NDI_GOLD 		=> 11,
    NDI_TAN  		=> 12,
    NDI_MAX_COLOR	=> 12,
-   NDI_COLOR_MASK	=> 0xff,
-   NDI_UNIQUE	=> 0x100,
-   NDI_ALL  		=> 0x200,
+   NDI_COLOR_MASK	=> 0x1f,
+   NDI_REPLY	=> 0x20,
+   NDI_NOCRATE  => 0x40,
+   NDI_CLEAR	=> 0x80,
    a_none   		=> 0,
    a_readied		=> 1,
    a_wielded		=> 2,
